@@ -1,7 +1,7 @@
 from PymoNNto.Exploration.UI_Base import *
-from PymoNNto.NetworkBehaviour.Recorder.Recorder import *
+from PymoNNto.NetworkBehavior.Recorder.Recorder import *
 from PymoNNto.Exploration.Network_UI.Neuron_Classification_Colorizer import *
-from PymoNNto.NetworkBehaviour.Structure.Structure import *
+from PymoNNto.NetworkBehavior.Structure.Structure import *
 
 import numpy as np
 
@@ -20,9 +20,11 @@ class Network_UI(UI_Base):
         self.render_every_x_frames = 1
 
         for ng in network.NeuronGroups:
+            ng.is_visible = True
+
             if ng['NeuronDimension', 0] is None:
-                ng.add_behaviour(0, get_squared_dim(ng.size))
-                #network.add_behaviours_to_object({0: get_squared_dim(ng.size)}, ng)
+                ng.add_behavior(0, get_squared_dim(ng.size))
+                #network.add_behaviors_to_object({0: get_squared_dim(ng.size)}, ng)
 
             if not hasattr(ng, 'color'):
                 ng.color = (0, 0, 255, 255)
@@ -57,8 +59,6 @@ class Network_UI(UI_Base):
         self.update_without_state_change = False
         self.storage_manager = storage_manager
 
-        self.neuron_visible_groups = []
-
         self._neuron_select_group = network[group_tags[0], 0]
         self._neuron_select_mask = self._neuron_select_group.vector().astype(bool)#np.array([0])
         self._neuron_select_mask[0] = True
@@ -73,7 +73,7 @@ class Network_UI(UI_Base):
         if type(self.modules) is dict:
             self.modules = self.modules.values()
 
-        for beh in network.all_behaviours():
+        for beh in network.all_behaviors():
             for module in beh.get_UI_Tabs():
                 self.modules.append(module)
 
@@ -96,6 +96,9 @@ class Network_UI(UI_Base):
         self.timer.timeout.connect(self.on_timer)
         self.timer.start(40)
 
+    def get_visible_neuron_groups(self):# = [] neuron_visible_groups
+        return [ng for ng in self.network.NeuronGroups if ng.is_visible]
+
     def select_neuron_class(self, group, class_id, add_to_select_group=False):
         return self.select_neurons(group, group.classification == class_id, add_to_select_group)
 
@@ -160,8 +163,8 @@ class Network_UI(UI_Base):
 
                 for rec_length in rec_time_dict:
                     rec = Recorder(rec_time_dict[rec_length] + ['iteration'], tag='UI_rec,rec_' + str(rec_length), max_length=rec_length)
-                    group.add_behaviour(10000+rec_length, rec)
-                    #self.network.add_behaviours_to_object({10000+rec_length: rec}, group)
+                    group.add_behavior(10000+rec_length, rec)
+                    #self.network.add_behaviors_to_object({10000+rec_length: rec}, group)
 
 
     def static_update_func(self, event=None):
